@@ -20,8 +20,6 @@
 
 #include "texttospeechconfigurationwidget.h"
 
-#include <QTextCodec>
-
 #include <KLocalizedString>
 
 #include "speech.h"
@@ -36,21 +34,20 @@ TextToSpeechConfigurationWidget::TextToSpeechConfigurationWidget(QWidget *parent
     setupUi(this);
     ttsSystem = new TextToSpeechSystem(this);
 
-    connect(qtspeechGroupBox, &QGroupBox::toggled,
-            this, &TextToSpeechConfigurationWidget::useQtspeechChanged);
+    connect(qtspeechGroupBox, &QGroupBox::toggled, this, &TextToSpeechConfigurationWidget::useQtspeechChanged);
     buildCodecList();
 
     // BEGIN Text-to-speech section
     // Populate tts engines and use their names directly as key and item text:
     const QStringList engines = QTextToSpeech::availableEngines();
     for (const QString &engine : engines) {
-        engineComboBox->addItem(engine);
+        if (engine != QLatin1String("mock")) {
+            engineComboBox->addItem(engine);
+        }
     }
 
-    connect(engineComboBox, qOverload<int>(&QComboBox::currentIndexChanged),
-            this, &TextToSpeechConfigurationWidget::slotTTSEngineChanged);
-    connect(voiceComboBox, &QComboBox::currentTextChanged,
-            this, &TextToSpeechConfigurationWidget::slotTTSVoiceChanged);
+    connect(engineComboBox, qOverload<int>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigurationWidget::slotTTSEngineChanged);
+    connect(voiceComboBox, &QComboBox::currentTextChanged, this, &TextToSpeechConfigurationWidget::slotTTSVoiceChanged);
 
     // Preload voice list
     slotTTSEngineChanged();
@@ -62,20 +59,17 @@ TextToSpeechConfigurationWidget::~TextToSpeechConfigurationWidget()
 
 void TextToSpeechConfigurationWidget::buildCodecList()
 {
-    QString local = i18nc("Local characterset", "Local") + QStringLiteral(" (");
-    local += QLatin1String(QTextCodec::codecForLocale()->name()) + QLatin1Char(')');
-    characterCodingBox->addItem(local, Speech::Local);
-    characterCodingBox->addItem(i18nc("Latin1 characterset", "Latin1"), Speech::Latin1);
-    characterCodingBox->addItem(i18n("Unicode"), Speech::Unicode);
-    for (int i = 0; i < ttsSystem->codecList->count(); i++)
-        characterCodingBox->addItem(QLatin1String(ttsSystem->codecList->at(i)->name()), Speech::UseCodec + i);
+    for (int encoding = QStringConverter::System; encoding <= QStringConverter::System; ++encoding) {
+        QString name = QLatin1String(QStringConverter::nameForEncoding(QStringConverter::Encoding(encoding)));
+        characterCodingBox->addItem(name, encoding);
+    }
 }
 
 void TextToSpeechConfigurationWidget::cancel()
 {
     urlReq->setUrl(QUrl::fromLocalFile(ttsSystem->ttsCommand));
     stdInButton->setChecked(ttsSystem->stdIn);
-    characterCodingBox->setCurrentIndex(ttsSystem->codec);
+    characterCodingBox->setCurrentIndex(ttsSystem->encoding);
     qtspeechGroupBox->setChecked(ttsSystem->useQtSpeech);
 }
 
@@ -91,7 +85,7 @@ void TextToSpeechConfigurationWidget::slotTTSEngineChanged()
 
     // Get list of voices and repopulate voice tts combobox
     QTextToSpeech *ttsEngine = new QTextToSpeech(engine);
-    const QVector<QVoice> voices = ttsEngine->availableVoices();
+    const QList<QVoice> voices = ttsEngine->availableVoices();
     voiceComboBox->blockSignals(true);
     voiceComboBox->clear();
     for (const QVoice &voice : voices) {
@@ -115,7 +109,7 @@ void TextToSpeechConfigurationWidget::ok()
 {
     ttsSystem->ttsCommand = urlReq->url().toLocalFile();
     ttsSystem->stdIn = stdInButton->isChecked();
-    ttsSystem->codec = characterCodingBox->currentIndex();
+    ttsSystem->encoding = QStringConverter::Encoding(characterCodingBox->currentIndex());
     ttsSystem->useQtSpeech = qtspeechGroupBox->isChecked();
 }
 
@@ -129,7 +123,7 @@ void TextToSpeechConfigurationWidget::readOptions(const QString &langGroup)
     ttsSystem->readOptions(langGroup);
     urlReq->setUrl(QUrl::fromLocalFile(ttsSystem->ttsCommand));
     stdInButton->setChecked(ttsSystem->stdIn);
-    characterCodingBox->setCurrentIndex(ttsSystem->codec);
+    characterCodingBox->setCurrentIndex(ttsSystem->encoding);
     qtspeechGroupBox->setChecked(ttsSystem->useQtSpeech);
     engineComboBox->setCurrentText(ttsSystem->ttsEngine);
 
@@ -142,4 +136,3 @@ void TextToSpeechConfigurationWidget::saveOptions(const QString &langGroup)
 {
     ttsSystem->saveOptions(langGroup);
 }
-
